import React from "react";
import { KeyValueTable, InternalLink, EmptyValue } from "@ess-ics/ce-ui-common";
import { Stack, Typography } from "@mui/material";

export const HostDetailsTable = ({ host }) => {
  function listToString(list) {
    if (list) {
      if (Array.isArray(list)) {
        return list.join(", ");
      }
      return list;
    }

    return "";
  }

  function renderVmOwners(owners) {
    if (owners && owners.length > 0) {
      return (
        <Stack
          direction="row"
          flexWrap="wrap"
          divider={<Typography component="span">,&nbsp;</Typography>}
        >
          {owners.map((username) => (
            <InternalLink
              to={`/user/${username}`}
              label={`${username} VM Owner User profile`}
              key={username}
            >
              {username}
            </InternalLink>
          ))}
        </Stack>
      );
    } else {
      return <EmptyValue />;
    }
  }

  const obj = {
    "device type": host?.netBoxHost?.deviceType,
    description: host?.netBoxHost?.description,
    scope: host?.netBoxHost?.scope,
    "vm owner": renderVmOwners(host?.netBoxHost?.vmOwner),
    "ansible groups": listToString(host?.netBoxHost?.ansibleGroups)
  };

  return (
    <KeyValueTable
      obj={obj}
      variant="overline"
    />
  );
};
